@@ -165,15 +165,20 @@ sub build_binaries {
     @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib];
     #if ($^O eq 'openbsd') {
     #  warn "###WARN### skipping im_process on OpenBSD";
-    #  @imtargets = grep { $_ !~ /^(im_process)$/ } @imtargets;
+    #  @imtargets = grep { $_ !~ /^im_process$/ } @imtargets;
     #}
     #if ($^O eq 'solaris') {
     #  warn "###WARN### skipping iuptuio on Solaris";
-    #  @iuptargets = grep { $_ !~ /^(iuptuio)$/ } @iuptargets;
+    #  @iuptargets = grep { $_ !~ /^iuptuio$/ } @iuptargets;
     #}
+    if ($^O eq 'solaris') {
+      warn "###WARN### skipping iup_mglplot on Solaris (fails to compile)";
+      @iuptargets = grep { $_ !~ /^iup_mglplot$/ } @iuptargets;
+    }
   }
 
   @cdtargets  = grep { $_ !~ /^(cd_ftgl|cdgl)$/ } @cdtargets unless $has{l_GLU};
+  @iuptargets = grep { $_ !~ /^(iup_mglplot)$/ } @iuptargets unless $has{gl} && $has{glu};
   @iuptargets = grep { $_ !~ /^(iupgl)$/ } @iuptargets unless $has{glx};
   @iuptargets = grep { $_ !~ /^(iupweb)$/ } @iuptargets unless $has{webkit};
 
@@ -214,7 +219,7 @@ sub build_binaries {
     my $msg = "\nYou have the following build options available:\n" .
               join("\n", map ($n++ . ") $_", @build_opts)) .
 	      "\nWhat do you wanna build?";
-    my $i = $self->prompt($msg, 1);
+    my $i = $ENV{TRAVIS} ? 1 : $self->prompt($msg, 1);
     $build_target = $build_opts[$i-1];
     die "###ERROR### Wrong selection!" unless $build_target;
   }
